# Contributors 

DM @hobson if you would like to participate in the weekly Zoom collaborative-programming sessions.

## Active contributors
- Hobson (@hobson): infrastructure (CI, webapp) and framework features (nltk->spacy, USE vectors)
- Olesya Bondarenko(@ovbondarenko): `ElasticSearch` and `nboost`
- Travis Harper (@travis-harper): markhov chain reply selection and other data science enhancements
- Mohammed Dala ([@dala85](https://github.com/dala85)): django web application
- Maria Dyshel (@maria_tangibleai): documentation and emotional support 

## Past Contributors (alphabetically)

- Erturgrul: Turkish wikipedia QA bot (parul bot)
- Kendra Chalk (@kchalk): semantic search
- Nima (@hulkgeek): question answering bot based on his state of the art question classifier
- Prarit (@praritlamba): BERT
- Xavier (@spirovanni): employment counselor for workforce.org and the city of San Diego
- **YOU:** What AI idea would you like to make a reality?